import React, { CSSProperties, HTMLAttributes } from 'react';
import { Elements, NodeTypesType, EdgeTypesType, OnLoadFunc, Node, Edge, Connection, ConnectionLineType } from '../../types';
import '../../style.css';
export interface ReactFlowProps extends Omit<HTMLAttributes<HTMLDivElement>, 'onLoad'> {
    elements: Elements;
    onElementClick?: (element: Node | Edge) => void;
    onElementsRemove?: (elements: Elements) => void;
    onNodeDragStart?: (node: Node) => void;
    onNodeDragStop?: (node: Node) => void;
    onConnect?: (connection: Edge | Connection) => void;
    onLoad?: OnLoadFunc;
    onMove?: () => void;
    onSelectionChange?: (elements: Elements | null) => void;
    nodeTypes: NodeTypesType;
    edgeTypes: EdgeTypesType;
    connectionLineType: ConnectionLineType;
    connectionLineStyle?: CSSProperties;
    deleteKeyCode: number;
    selectionKeyCode: number;
    snapToGrid: boolean;
    snapGrid: [number, number];
    onlyRenderVisibleNodes: boolean;
    isInteractive: boolean;
    selectNodesOnDrag: boolean;
    minZoom: number;
    maxZoom: number;
    defaultZoom: number;
}
declare const ReactFlow: {
    ({ style, onElementClick, elements, className, children, nodeTypes, edgeTypes, onLoad, onMove, onElementsRemove, onConnect, onNodeDragStart, onNodeDragStop, onSelectionChange, connectionLineType, connectionLineStyle, deleteKeyCode, selectionKeyCode, snapToGrid, snapGrid, onlyRenderVisibleNodes, isInteractive, selectNodesOnDrag, minZoom, maxZoom, defaultZoom, }: ReactFlowProps): JSX.Element;
    displayName: string;
    defaultProps: {
        nodeTypes: {
            input: React.MemoExoticComponent<({ data, sourcePosition }: import("../../types").NodeProps) => JSX.Element>;
            default: React.MemoExoticComponent<({ data, targetPosition, sourcePosition }: import("../../types").NodeProps) => JSX.Element>;
            output: React.MemoExoticComponent<({ data, targetPosition }: import("../../types").NodeProps) => JSX.Element>;
        };
        edgeTypes: {
            default: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, sourcePosition, targetPosition, label, labelStyle, labelShowBg, labelBgStyle, style, }: import("../../types").EdgeBezierProps) => JSX.Element>;
            straight: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, style }: import("../../types").EdgeProps) => JSX.Element>;
            step: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, style }: import("../../types").EdgeProps) => JSX.Element>;
        };
        connectionLineType: ConnectionLineType;
        deleteKeyCode: number;
        selectionKeyCode: number;
        snapToGrid: boolean;
        snapGrid: number[];
        onlyRenderVisibleNodes: boolean;
        isInteractive: boolean;
        selectNodesOnDrag: boolean;
        minZoom: number;
        maxZoom: number;
        defaultZoom: number;
    };
};
export default ReactFlow;
